{
    "$graph": [
        {
            "class": "Workflow",
            "label": "bgzip and index VCF",
            "inputs": [
                {
                    "type": "File",
                    "id": "#bgzip_and_index.cwl/vcf"
                }
            ],
            "steps": [
                {
                    "run": "#bgzip.cwl",
                    "in": [
                        {
                            "source": "#bgzip_and_index.cwl/vcf",
                            "id": "#bgzip_and_index.cwl/bgzip/file"
                        }
                    ],
                    "out": [
                        "#bgzip_and_index.cwl/bgzip/bgzipped_file"
                    ],
                    "id": "#bgzip_and_index.cwl/bgzip"
                },
                {
                    "run": "#index_vcf.cwl",
                    "in": [
                        {
                            "source": "#bgzip_and_index.cwl/bgzip/bgzipped_file",
                            "id": "#bgzip_and_index.cwl/index/vcf"
                        }
                    ],
                    "out": [
                        "#bgzip_and_index.cwl/index/indexed_vcf"
                    ],
                    "id": "#bgzip_and_index.cwl/index"
                }
            ],
            "id": "#bgzip_and_index.cwl",
            "outputs": [
                {
                    "type": "File",
                    "outputSource": "#bgzip_and_index.cwl/index/indexed_vcf",
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "id": "#bgzip_and_index.cwl/indexed_vcf"
                }
            ]
        },
        {
            "class": "Workflow",
            "label": "phase VCF",
            "requirements": [
                {
                    "class": "SubworkflowFeatureRequirement"
                },
                {
                    "class": "StepInputExpressionRequirement"
                },
                {
                    "class": "InlineJavascriptRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "secondaryFiles": "${if (self.nameext === \".bam\") {return self.basename + \".bai\"} else {return self.basename + \".crai\"}}",
                    "id": "#main/bam"
                },
                {
                    "type": "File",
                    "id": "#main/germline_vcf"
                },
                {
                    "type": "string",
                    "id": "#main/normal_sample_name"
                },
                {
                    "type": [
                        "string",
                        "File"
                    ],
                    "secondaryFiles": [
                        ".fai",
                        "^.dict"
                    ],
                    "id": "#main/reference"
                },
                {
                    "type": "File",
                    "id": "#main/reference_dict"
                },
                {
                    "type": "File",
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "id": "#main/somatic_vcf"
                },
                {
                    "type": "string",
                    "id": "#main/tumor_sample_name"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputSource": "#main/bgzip_and_index_phased_vcf/indexed_vcf",
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "id": "#main/phased_vcf"
                }
            ],
            "steps": [
                {
                    "run": "#bgzip_and_index.cwl",
                    "in": [
                        {
                            "source": "#main/sort/sorted_vcf",
                            "id": "#main/bgzip_and_index/vcf"
                        }
                    ],
                    "out": [
                        "#main/bgzip_and_index/indexed_vcf"
                    ],
                    "id": "#main/bgzip_and_index"
                },
                {
                    "run": "#bgzip_and_index.cwl",
                    "in": [
                        {
                            "source": "#main/phase_vcf/phased_vcf",
                            "id": "#main/bgzip_and_index_phased_vcf/vcf"
                        }
                    ],
                    "out": [
                        "#main/bgzip_and_index_phased_vcf/indexed_vcf"
                    ],
                    "id": "#main/bgzip_and_index_phased_vcf"
                },
                {
                    "run": "#pvacseq_combine_variants.cwl",
                    "in": [
                        {
                            "source": "#main/index_renamed_germline/indexed_vcf",
                            "id": "#main/combine_variants/germline_vcf"
                        },
                        {
                            "source": "#main/reference",
                            "id": "#main/combine_variants/reference"
                        },
                        {
                            "source": "#main/index_filtered_somatic/indexed_vcf",
                            "id": "#main/combine_variants/somatic_vcf"
                        }
                    ],
                    "out": [
                        "#main/combine_variants/combined_vcf"
                    ],
                    "id": "#main/combine_variants"
                },
                {
                    "run": "#index_vcf.cwl",
                    "in": [
                        {
                            "source": "#main/select_somatic_tumor_sample/filtered_vcf",
                            "id": "#main/index_filtered_somatic/vcf"
                        }
                    ],
                    "out": [
                        "#main/index_filtered_somatic/indexed_vcf"
                    ],
                    "id": "#main/index_filtered_somatic"
                },
                {
                    "run": "#index_vcf.cwl",
                    "in": [
                        {
                            "source": "#main/rename_germline_vcf/renamed_vcf",
                            "id": "#main/index_renamed_germline/vcf"
                        }
                    ],
                    "out": [
                        "#main/index_renamed_germline/indexed_vcf"
                    ],
                    "id": "#main/index_renamed_germline"
                },
                {
                    "run": "#read_backed_phasing.cwl",
                    "in": [
                        {
                            "source": "#main/bam",
                            "id": "#main/phase_vcf/bam"
                        },
                        {
                            "source": "#main/reference",
                            "id": "#main/phase_vcf/reference"
                        },
                        {
                            "source": "#main/bgzip_and_index/indexed_vcf",
                            "id": "#main/phase_vcf/vcf"
                        }
                    ],
                    "out": [
                        "#main/phase_vcf/phased_vcf"
                    ],
                    "id": "#main/phase_vcf"
                },
                {
                    "run": "#replace_vcf_sample_name.cwl",
                    "in": [
                        {
                            "source": "#main/germline_vcf",
                            "id": "#main/rename_germline_vcf/input_vcf"
                        },
                        {
                            "source": "#main/tumor_sample_name",
                            "id": "#main/rename_germline_vcf/new_sample_name"
                        },
                        {
                            "source": "#main/normal_sample_name",
                            "id": "#main/rename_germline_vcf/sample_to_replace"
                        }
                    ],
                    "out": [
                        "#main/rename_germline_vcf/renamed_vcf"
                    ],
                    "id": "#main/rename_germline_vcf"
                },
                {
                    "run": "#select_variants.cwl",
                    "in": [
                        {
                            "default": "somatic_tumor_only",
                            "id": "#main/select_somatic_tumor_sample/output_vcf_basename"
                        },
                        {
                            "source": "#main/reference",
                            "id": "#main/select_somatic_tumor_sample/reference"
                        },
                        {
                            "source": "#main/tumor_sample_name",
                            "valueFrom": "${ return [self]; }",
                            "id": "#main/select_somatic_tumor_sample/samples_to_include"
                        },
                        {
                            "source": "#main/somatic_vcf",
                            "id": "#main/select_somatic_tumor_sample/vcf"
                        }
                    ],
                    "out": [
                        "#main/select_somatic_tumor_sample/filtered_vcf"
                    ],
                    "id": "#main/select_somatic_tumor_sample"
                },
                {
                    "run": "#sort_vcf.cwl",
                    "in": [
                        {
                            "source": "#main/reference_dict",
                            "id": "#main/sort/reference_dict"
                        },
                        {
                            "source": "#main/combine_variants/combined_vcf",
                            "id": "#main/sort/vcf"
                        }
                    ],
                    "out": [
                        "#main/sort/sorted_vcf"
                    ],
                    "id": "#main/sort"
                }
            ],
            "id": "#main"
        },
        {
            "class": "CommandLineTool",
            "label": "bgzip VCF",
            "baseCommand": [
                "/opt/htslib/bin/bgzip"
            ],
            "requirements": [
                {
                    "class": "DockerRequirement",
                    "dockerPull": "mgibio/samtools-cwl:1.0.0"
                },
                {
                    "class": "ResourceRequirement",
                    "ramMin": 4000
                }
            ],
            "stdout": "$(inputs.file.basename).gz",
            "arguments": [
                "-c"
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 1
                    },
                    "id": "#bgzip.cwl/file"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "id": "#bgzip.cwl/bgzipped_file",
                    "outputBinding": {
                        "glob": "$(inputs.file.basename).gz"
                    }
                }
            ],
            "id": "#bgzip.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "vcf index",
            "arguments": [
                "cp",
                "$(inputs.vcf.path)",
                "$(runtime.outdir)/$(inputs.vcf.basename)",
                {
                    "valueFrom": " && ",
                    "shellQuote": false
                },
                "/usr/bin/tabix",
                "-p",
                "vcf"
            ],
            "requirements": [
                {
                    "class": "ShellCommandRequirement"
                },
                {
                    "class": "DockerRequirement",
                    "dockerPull": "mgibio/samtools-cwl:1.0.0"
                },
                {
                    "class": "ResourceRequirement",
                    "ramMin": 4000
                },
                {
                    "class": "StepInputExpressionRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "valueFrom": "$(self.basename)",
                        "position": 1
                    },
                    "id": "#index_vcf.cwl/vcf"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "outputBinding": {
                        "glob": "$(inputs.vcf.basename)"
                    },
                    "id": "#index_vcf.cwl/indexed_vcf"
                }
            ],
            "id": "#index_vcf.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "Combine germline and somatic vcf for pVACseq phasing",
            "baseCommand": [
                "/usr/bin/java",
                "-Xmx8g",
                "-jar",
                "/opt/GenomeAnalysisTK.jar",
                "-T",
                "CombineVariants"
            ],
            "requirements": [
                {
                    "class": "ResourceRequirement",
                    "ramMin": 9000,
                    "tmpdirMin": 25000
                },
                {
                    "class": "DockerRequirement",
                    "dockerPull": "mgibio/gatk-cwl:3.6.0"
                }
            ],
            "arguments": [
                "--assumeIdenticalSamples",
                "-o",
                {
                    "valueFrom": "$(runtime.outdir)/combined_somatic_plus_germline.vcf"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "-V",
                        "position": 2
                    },
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "id": "#pvacseq_combine_variants.cwl/germline_vcf"
                },
                {
                    "type": [
                        "string",
                        "File"
                    ],
                    "secondaryFiles": [
                        ".fai",
                        "^.dict"
                    ],
                    "inputBinding": {
                        "prefix": "-R",
                        "position": 1
                    },
                    "id": "#pvacseq_combine_variants.cwl/reference"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "-V",
                        "position": 3
                    },
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "id": "#pvacseq_combine_variants.cwl/somatic_vcf"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "combined_somatic_plus_germline.vcf"
                    },
                    "id": "#pvacseq_combine_variants.cwl/combined_vcf"
                }
            ],
            "id": "#pvacseq_combine_variants.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "Read-backed phasing",
            "baseCommand": [
                "/usr/bin/java",
                "-Xmx8g",
                "-jar",
                "/opt/GenomeAnalysisTK.jar",
                "-T",
                "ReadBackedPhasing"
            ],
            "requirements": [
                {
                    "class": "ResourceRequirement",
                    "ramMin": 9000,
                    "tmpdirMin": 25000
                },
                {
                    "class": "DockerRequirement",
                    "dockerPull": "mgibio/gatk-cwl:3.6.0"
                }
            ],
            "arguments": [
                "-L",
                {
                    "valueFrom": "$(inputs.vcf)"
                },
                "-o",
                {
                    "valueFrom": "$(runtime.outdir)/phased.vcf"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "-I",
                        "position": 2
                    },
                    "secondaryFiles": "${if (self.nameext === \".bam\") {return self.basename + \".bai\"} else {return self.basename + \".crai\"}}",
                    "id": "#read_backed_phasing.cwl/bam"
                },
                {
                    "type": [
                        "string",
                        "File"
                    ],
                    "secondaryFiles": [
                        ".fai",
                        "^.dict"
                    ],
                    "inputBinding": {
                        "prefix": "-R",
                        "position": 1
                    },
                    "id": "#read_backed_phasing.cwl/reference"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "-V",
                        "position": 3
                    },
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "id": "#read_backed_phasing.cwl/vcf"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "phased.vcf"
                    },
                    "id": "#read_backed_phasing.cwl/phased_vcf"
                }
            ],
            "id": "#read_backed_phasing.cwl"
        },
        {
            "class": "CommandLineTool",
            "baseCommand": [
                "/bin/bash",
                "rename_sample.sh"
            ],
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                },
                {
                    "class": "ResourceRequirement",
                    "ramMin": 8000
                },
                {
                    "class": "DockerRequirement",
                    "dockerPull": "mgibio/bcftools-cwl:1.9"
                },
                {
                    "class": "InitialWorkDirRequirement",
                    "listing": [
                        {
                            "entryname": "rename_sample.sh",
                            "entry": "#!/bin/bash\nset -eou pipefail\nbasen=`basename \"$3\"`\nbasen=\"renamed.$basen\"\n\n#escape spaces, otherwise bcftools will try to use them as a delimiter\n#triple backslash to escape within backticks and then again within sed\nold_name=`echo \"$1\" | sed 's/ /\\\\\\ /g'`\nnew_name=`echo \"$2\" | sed 's/ /\\\\\\ /g'`\n\necho \"$old_name $new_name\" > sample_update.txt\n/opt/bcftools/bin/bcftools reheader -s sample_update.txt -o \"$basen\" \"$3\"\n"
                        }
                    ]
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 3
                    },
                    "doc": "vcf file to filter",
                    "id": "#replace_vcf_sample_name.cwl/input_vcf"
                },
                {
                    "type": "string",
                    "inputBinding": {
                        "position": 2
                    },
                    "doc": "Sample name to replace the other",
                    "id": "#replace_vcf_sample_name.cwl/new_sample_name"
                },
                {
                    "type": "string",
                    "inputBinding": {
                        "position": 1
                    },
                    "doc": "Sample name to be replaced",
                    "id": "#replace_vcf_sample_name.cwl/sample_to_replace"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(\"renamed.\" + inputs.input_vcf.basename)"
                    },
                    "id": "#replace_vcf_sample_name.cwl/renamed_vcf"
                }
            ],
            "id": "#replace_vcf_sample_name.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "SelectVariants (GATK 3.6)",
            "baseCommand": [
                "/usr/bin/java",
                "-Xmx4g",
                "-jar",
                "/opt/GenomeAnalysisTK.jar",
                "-T",
                "SelectVariants"
            ],
            "requirements": [
                {
                    "class": "ResourceRequirement",
                    "ramMin": 6000,
                    "tmpdirMin": 25000
                },
                {
                    "class": "DockerRequirement",
                    "dockerPull": "mgibio/gatk-cwl:3.6.0"
                }
            ],
            "arguments": [
                "-o",
                {
                    "valueFrom": "$(runtime.outdir)/$(inputs.output_vcf_basename).vcf.gz"
                }
            ],
            "inputs": [
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "prefix": "--excludeFiltered",
                        "position": 4
                    },
                    "id": "#select_variants.cwl/exclude_filtered"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "inputBinding": {
                        "prefix": "-L",
                        "position": 3
                    },
                    "id": "#select_variants.cwl/interval_list"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "default": "select_variants",
                    "id": "#select_variants.cwl/output_vcf_basename"
                },
                {
                    "type": [
                        "string",
                        "File"
                    ],
                    "secondaryFiles": [
                        ".fai",
                        "^.dict"
                    ],
                    "inputBinding": {
                        "prefix": "-R",
                        "position": 1
                    },
                    "id": "#select_variants.cwl/reference"
                },
                {
                    "type": [
                        "null",
                        {
                            "type": "array",
                            "items": "string"
                        }
                    ],
                    "inputBinding": {
                        "prefix": "--sample_name",
                        "position": 5
                    },
                    "doc": "include genotypes from this sample",
                    "id": "#select_variants.cwl/samples_to_include"
                },
                {
                    "type": [
                        "null",
                        {
                            "type": "enum",
                            "symbols": [
                                "#select_variants.cwl/select_type/INDEL",
                                "#select_variants.cwl/select_type/SNP",
                                "#select_variants.cwl/select_type/MIXED",
                                "#select_variants.cwl/select_type/MNP",
                                "#select_variants.cwl/select_type/SYMBOLIC",
                                "#select_variants.cwl/select_type/NO_VARIATION"
                            ]
                        }
                    ],
                    "inputBinding": {
                        "prefix": "-selectType",
                        "position": 6
                    },
                    "doc": "select only a certain type of variants",
                    "id": "#select_variants.cwl/select_type"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "--variant",
                        "position": 2
                    },
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "id": "#select_variants.cwl/vcf"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "outputBinding": {
                        "glob": "$(inputs.output_vcf_basename).vcf.gz"
                    },
                    "id": "#select_variants.cwl/filtered_vcf"
                }
            ],
            "id": "#select_variants.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "Sort VCF",
            "baseCommand": [
                "/usr/bin/java",
                "-Xmx16g",
                "-jar",
                "/opt/picard/picard.jar",
                "SortVcf"
            ],
            "arguments": [
                "O=",
                {
                    "valueFrom": "$(runtime.outdir)/sorted.vcf"
                }
            ],
            "requirements": [
                {
                    "class": "ResourceRequirement",
                    "ramMin": 18000
                },
                {
                    "class": "DockerRequirement",
                    "dockerPull": "mgibio/picard-cwl:2.18.1"
                }
            ],
            "inputs": [
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "inputBinding": {
                        "prefix": "SEQUENCE_DICTIONARY="
                    },
                    "id": "#sort_vcf.cwl/reference_dict"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "I="
                    },
                    "id": "#sort_vcf.cwl/vcf"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "sorted.vcf"
                    },
                    "id": "#sort_vcf.cwl/sorted_vcf"
                }
            ],
            "id": "#sort_vcf.cwl"
        }
    ],
    "cwlVersion": "v1.0"
}
